"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initSellingResource = void 0;
const amman_1 = require("@metaplex-foundation/amman");
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("../../src/utils");
const utils_2 = require("../utils");
const createTokenAccount_1 = require("../transactions/createTokenAccount");
const mintNft_1 = require("./mintNft");
const instructions_1 = require("../../src/instructions");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const initSellingResource = ({ test, transactionHandler, payer, connection, store, maxSupply, }) => __awaiter(void 0, void 0, void 0, function* () {
    const creator = new mpl_token_metadata_1.Creator({
        address: payer.publicKey.toBase58(),
        share: 100,
        verified: true,
    });
    const { edition: masterEdition, editionBump: masterEditionBump, tokenAccount: resourceToken, mint: resourceMint, metadata, } = yield (0, mintNft_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
        creators: [creator],
    });
    const [vaultOwner, vaultOwnerBump] = yield (0, utils_1.findVaultOwnerAddress)(resourceMint.publicKey, store);
    const { tokenAccount: vault, createTokenTx } = yield (0, createTokenAccount_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: resourceMint.publicKey,
        connection,
        owner: vaultOwner,
    });
    const createVaultRes = yield transactionHandler.sendAndConfirmTransaction(createTokenTx, [vault], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(test, createVaultRes.txConfirmed);
    const sellingResource = web3_js_1.Keypair.generate();
    const initSellingResourceInstruction = (0, instructions_1.createInitSellingResourceInstruction)({
        store,
        admin: payer.publicKey,
        sellingResource: sellingResource.publicKey,
        sellingResourceOwner: payer.publicKey,
        metadata,
        masterEdition,
        resourceMint: resourceMint.publicKey,
        resourceToken: resourceToken.publicKey,
        vault: vault.publicKey,
        owner: vaultOwner,
    }, {
        masterEditionBump,
        vaultOwnerBump,
        maxSupply,
    });
    const initSellingResourceTx = yield (0, utils_2.createAndSignTransaction)(connection, payer, [initSellingResourceInstruction], [sellingResource]);
    const initSellingResourceRes = yield transactionHandler.sendAndConfirmTransaction(initSellingResourceTx, [sellingResource], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)(`selling-resource: ${sellingResource.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(test, initSellingResourceRes.txConfirmed);
    return {
        sellingResource,
        vault,
        vaultOwner,
        vaultOwnerBump,
        resourceMint,
    };
});
exports.initSellingResource = initSellingResource;
//# sourceMappingURL=initSellingResource.js.map